==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/br.js <==
OC.L10N.register(
    "tasks",
    {
    "Today" : "Hiziv",
    "Week" : "Sizun",
    "All" : "Pep tra",
    "Current" : "A red",
    "Completed" : "Achuet",
    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
    "No users or groups" : "Implijourienn pe strodadoù ebet",
    "Can edit" : "Posuple eo embann",
    "Unshare with {displayName}" : "Dirannañ gant {displayName}",
    "Edit" : "Cheñch",
    "Copy private link" : "Eilañ al liamm prevez",
    "Delete" : "Dilemel",
    "Unshare" : "Nag eskemm ken",
    "Calendar link copied to clipboard." : "Liamm deizataer eilet d'ar golver",
    "Calendar link could not be copied to clipboard." : "Dibosup eo bet da eilañ al liamm deizataer er golver",
    "An error occurred, unable to delete the calendar." : "Ur fazi a zo bet,  dibosupl lemel an deizataer.",
    "Name" : "Anv",
    "Deleted" : "Lamet",
    "Restore" : "Adkrouiñ",
    "Delete permanently" : "Lamet da viken",
    "Empty trash bin" : "Pod-lastez goullo",
    "Cancel" : "Arrest",
    "Close" : "Seriñ",
    "[Yesterday]" : "[Dec'h]",
    "[Today]" : "[Hiziv]",
    "[Tomorrow]" : "[Warc'hoazh]",
    "Tomorrow" : "Warc'hoaz",
    "Details" : "Munudoù",
    "Notes" : "Notennoù",
    "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
    "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
    "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
    "Canceled" : "Nullet"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/br.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Important",
    "Today" : "Hiziv",
    "Week" : "Sizun",
    "All" : "Pep tra",
    "Current" : "A red",
    "Completed" : "Achuet",
    "Hidden" : "Koachet",
    "Automatic" : "Otomatek",
    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
    "No users or groups" : "Implijourienn pe strodadoù ebet",
    "Can edit" : "Posuple eo embann",
    "Unshare with {displayName}" : "Dirannañ gant {displayName}",
    "Calendar link copied to clipboard." : "Liamm deizataer eilet d'ar golver",
    "Calendar link could not be copied to clipboard." : "Dibosup eo bet da eilañ al liamm deizataer er golver",
    "An error occurred, unable to delete the calendar." : "Ur fazi a zo bet,  dibosupl lemel an deizataer.",
    "Edit" : "Cheñch",
    "Copy private link" : "Eilañ al liamm prevez",
    "Delete" : "Dilemel",
    "Unshare" : "Nag eskemm ken",
    "Empty trash bin" : "Pod-lastez goullo",
    "Name" : "Anv",
    "Deleted" : "Dilamet",
    "Restore" : "Adkrouiñ",
    "Delete permanently" : "Dilemel da viken",
    "Cancel" : "Nullañ",
    "Notification" : "Kemennadenn",
    "Email" : "Postel",
    "Close" : "Seriñ",
    "Alphabetically" : "Urzh alfabetek",
    "Tags" : "Klavioù",
    "[Yesterday]" : "[Dec'h]",
    "[Today]" : "[Hiziv]",
    "[Tomorrow]" : "[Warc'hoazh]",
    "Tomorrow" : "Warc'hoaz",
    "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
    "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
    "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
    "Canceled" : "Nullet",
    "Details" : "Munudoù",
    "Notes" : "Notennoù"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
